Laplacian: The Laplacian of a graph

View source: R/Laplacian.R

LaplacianR Documentation

The Laplacian of a graph

Description

The (symmetric) Laplacian of a graph is a square matrix with dimention equal the number of nodes. It is defined as

L_{ij} = n_i \textrm{ if } i=j, -1 \textrm{ if } i\sim j, 0 \textrm{ otherwise}

where i~j means that there is an edge between nodes i and j and n_i is the number of edges including node i.

Usage

Laplacian(x)

## Default S3 method:
Laplacian(x)

## S3 method for class 'matrix'
Laplacian(x)

## S3 method for class 'Matrix'
Laplacian(x)

Arguments

x

object defining a graph

Value

matrix as the Laplacian of a graph

Methods (by class)

  • Laplacian(default): The Laplacian default method (none)

  • Laplacian(matrix): The Laplacian of a matrix

  • Laplacian(Matrix): The Laplacian of a Matrix


graphpcor documentation built on March 23, 2026, 9:07 a.m.