basepcor-utils: Functions used by/to basepcor

basepcor-utilsR Documentation

Functions used by/to basepcor

Description

Functions used by/to basepcor

Usage

fillLprec(L, lfi)

Lprec0(theta, p, iLtheta, d0)

Arguments

L

matrix as the lower triangle containing the Cholesky decomposition of a initial precision matrix whose non-zeros are only at the position where the lower triangle side of the precision matrix is also non-zero

lfi

integer vector used as indicator of the position in the lower matrix where are the fill-in elements. Must be col then row ordered.

theta

numeric, the parameter vector.

p

integer (needed if base is vector): the dimension.

iLtheta

integer vector or 'graphpcor' to specify the (vectorized) position where 'theta' is placed in the initial (before the fill-in) Cholesky (lower triangle) factor. If missing, default, assumes the dense case as iLtheta = which(lower.tri(...)), giving length(theta)=p(p-1)/2.

d0

numeric vector to specify the diagonal of the Cholesky factor for the initial precision matrix Q0. Default, if not provided, is d0 = p:1.

Details

The (lower triangle) Cholesky factor of the initial precision for a correlation matrix contains the parameters in the non-zero elements of the lower triangle side of the precision matrix. The filled-in elements are computed from them using fillLprec().

Value

lower triangular matrix with the filled-in elements thus Q0 can be computed.

lower triangular matrix

Functions

  • fillLprec(): Function to fill-in a Cholesky matrix

  • Lprec0(): Compute the (lower triangle) Cholesky of the initial precision Q0.


graphpcor documentation built on March 23, 2026, 9:07 a.m.