cgeneric_LKJ: Build an 'cgeneric' model for the LKG prior on correlation...

View source: R/cgeneric_LKJ.R

cgeneric_LKJR Documentation

Build an cgeneric model for the LKG prior on correlation matrix.

Description

Build an cgeneric model for the LKG prior on correlation matrix.

Usage

cgeneric_LKJ(
  n,
  eta,
  sigma.prior.reference = rep(1, n),
  sigma.prior.probability = rep(NA, n),
  ...
)

Arguments

n

integer to define the size of the matrix

eta

numeric greater than 1, the parameter

sigma.prior.reference

numeric vector with length n, n is the number of nodes (variables) in the graph, as the reference standard deviation to define the PC prior for each marginal variance parameters. If missing, the model will be assumed for a correlation. If a length n vector is given and sigma.prior.reference is missing, it will be used as known square root of the variances.

sigma.prior.probability

numeric vector with length n to set the probability statement of the PC prior for each marginal variance parameters. The probability statement is P(sigma < sigma.prior.reference) = p. If missing, all the marginal variances are considered as known, as described in sigma.prior.reference. If a vector is given and a probability is NA, 0 or 1, the corresponding sigma.prior.reference will be used as fixed.

...

additional arguments passed to INLAtools::cgeneric().

Value

a cgeneric object, see INLAtools::cgeneric() for details.

See Also

It uses the Cannonical Partial Correlation (CPC), parametrization, see basecor() for details.


graphpcor documentation built on March 23, 2026, 9:07 a.m.