cgeneric_Wishart: Build an 'cgeneric' to implement the Wishart prior for a...

View source: R/cgeneric_Wishart.R

cgeneric_WishartR Documentation

Build an cgeneric to implement the Wishart prior for a precision matrix.

Description

Build an cgeneric to implement the Wishart prior for a precision matrix.

Usage

cgeneric_Wishart(n, dof, R, ...)

Arguments

n

integer to define the size of the precision matrix

dof

degrees of freedom model parameter

R

lower triangle of the scale matrix parameter

...

additional arguments passed on to INLAtools::cgeneric(), such as debug, shlib and useINLAprecomp.

Details

For a random p\times p precision matrix Q, given the parameters d and R, respectively scalar degree of freedom and the inverse scale p\times p matrix the Wishart density is

|Q|^{(d-p-1)/2}\textrm{e}^{-tr(RQ)/2}|R|^{p/2}2^{-dp/2}\Gamma_p(n/2)^{-1}

Value

a cgeneric, INLAtools::cgeneric() object.


graphpcor documentation built on March 23, 2026, 9:07 a.m.