graphpcor: graphpcor: correlation from nodes and edges

View source: R/graphpcor.R

Laplacian.graphpcorR Documentation

graphpcor: correlation from nodes and edges

Description

A graphpcor is a graph where a node represents a variable and an edge represent a conditional distribution. The correlation built from a graphpcor consider the parameters for the Cholesky of a precision matrix, whose non-zero pattern is given from the graph.

Usage

## S3 method for class 'graphpcor'
Laplacian(x)

graphpcor(...)

## S3 method for class 'list'
graphpcor(...)

## S3 method for class 'formula'
graphpcor(...)

## S3 method for class 'character'
graphpcor(...)

## S3 method for class 'matrix'
graphpcor(...)

## S3 method for class 'Matrix'
graphpcor(...)

## S3 method for class 'graphpcor'
print(x, ...)

## S3 method for class 'graphpcor'
summary(object, ...)

## S3 method for class 'graphpcor'
dim(x, ...)

## S3 method for class 'graphpcor'
plot(x, y, ...)

## S3 method for class 'graphpcor'
vcov(object, ...)

## S3 method for class 'graphpcor'
prec(model, ...)

## S3 method for class 'graphpcor'
cgeneric(model, ...)

## S3 method for class 'Matrix'
cgeneric(model, ...)

Arguments

x

graphpcor

...

matrix or Matrix (treated as binary) or a vector or list of formula (or character interpreted as formula)

object

graphpcor

y

not used

model

graphpcor model object

Methods (by class)

  • graphpcor(list): Each element may be a character or formula.

  • graphpcor(formula): Each term represents a node, and each ~ an edge.

  • graphpcor(character): Each term represents a node, and each ~ an edge.

  • graphpcor(matrix): Build a graphpcor from a matrix object

  • graphpcor(Matrix): Build a graphpcor for a Matrix object

Methods (by generic)

  • Laplacian(graphpcor): The Laplacian method for a graphpcor

  • print(graphpcor): The print method for graphpcor

  • summary(graphpcor): The summary method for graphpcor

  • dim(graphpcor): The dim method for graphpcor

  • plot(graphpcor): The plot method for a graphpcor

  • vcov(graphpcor): The vcov method for a graphpcor

  • prec(graphpcor): The precision method for 'graphpcor'

  • cgeneric(graphpcor): The cgeneric method for graphpcor uses cgeneric_graphpcor()

Functions

  • cgeneric(Matrix): The cgeneric method for Matrix uses cgeneric_graphpcor()


graphpcor documentation built on March 23, 2026, 9:07 a.m.