param-utils: Internal functions to map between Euclidean and spherical...

param-utilsR Documentation

Internal functions to map between Euclidean and spherical coordinates

Description

Internal functions to map between Euclidean and spherical coordinates

Usage

rphi2x(rphi)

x2rphi(x)

rtheta(n, lambda = 1, R, theta.base)

dtheta(theta, lambda, theta.base, H.elements)

Arguments

rphi

numeric vector where the first element is the radius and the remaining are the angles

x

parameters in the Euclidean space to be converted

n

integer to define the size of the correlation matrix

lambda

numeric as the parameter for the Exponential distribution of the radius

R

scaling matrix (square root of the Hessian around the base model)

theta.base

numeric vector of the base model

theta

numeric vector of length m.

H.elements

list output of theta2H

Details

For details, please see the wikipedia entry on 'N-sphere' at N-sphere

Functions

  • rphi2x(): Map between spherical to Euclidean coordinates

  • x2rphi(): Transform from Euclidean coordinates to spherical

  • rtheta(): Drawn samples from the PC-prior for correlation

  • dtheta(): PC-prior density for the correlation matrix


graphpcor documentation built on March 23, 2026, 9:07 a.m.