| basepcor-utils | R Documentation |
Functions used by/to basepcor
fillLprec(L, lfi)
Lprec0(theta, p, iLtheta, d0)
L |
matrix as the lower triangle containing the Cholesky decomposition of a initial precision matrix whose non-zeros are only at the position where the lower triangle side of the precision matrix is also non-zero |
lfi |
integer vector used as indicator of the position in the lower matrix where are the fill-in elements. Must be col then row ordered. |
theta |
numeric, the parameter vector. |
p |
integer (needed if |
iLtheta |
integer vector or 'graphpcor' to specify the (vectorized)
position where 'theta' is placed in the initial (before the fill-in)
Cholesky (lower triangle) factor. If missing, default, assumes
the dense case as |
d0 |
numeric vector to specify the diagonal of the
Cholesky factor for the initial precision matrix |
The (lower triangle) Cholesky factor
of the initial precision for a correlation matrix contains
the parameters in the non-zero elements of the lower triangle side
of the precision matrix.
The filled-in elements are computed from them using fillLprec().
lower triangular matrix with the filled-in
elements thus Q0 can be computed.
lower triangular matrix
fillLprec(): Function to fill-in a Cholesky matrix
Lprec0(): Compute the (lower triangle) Cholesky of the initial precision Q0.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.