View source: R/cgeneric_graphpcor.R
| cgeneric_graphpcor | R Documentation |
cgeneric for a (graph based) correlation matrix PC-prior.From either a graphpcor (see graphpcor()) or
a square matrix (used as a graph),
creates an cgeneric (see INLAtools::cgeneric())
to implement the Penalized Complexity prior using the
Kullback-Leibler divergence - KLD from a base graphpcor.
cgeneric_graphpcor(
model,
lambda,
base,
sigma.prior.reference,
sigma.prior.probability,
iparams,
cfixed,
d0,
...
)
model |
a |
lambda |
the parameter for the exponential prior on the radius of the sphere, see details in the PC-multivariate vignette. |
base |
numeric vector, correlation matrix or
|
sigma.prior.reference |
numeric vector to set the reference
for each standard deviation parameter for its PC-prior.
If missing, the model will be assumed as for a correlation.
Note: |
sigma.prior.probability |
numeric vector with to
set the probability statement of the PC prior for each
marginal variance parameters. The probability statement is
P(sigma < |
iparams |
integer vector with length equal |
cfixed |
integer vector to specify which correlation
parameters are treated as known and fixed.
By default all correlation parameters are treated as unknown.
Example: if |
d0 |
numeric vector to specify the diagonal of the
Cholesky factor for the initial precision matrix |
... |
additional arguments passed on to
|
The parametrization is set as in basepcor() and the base
is used to define an informative prior, as derived in
the pcmultivariate vignette.
cgeneric object.
graphpcor() and basepcor()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.