View source: R/cgeneric_pc_correl.R
| cgeneric_pc_correl | R Documentation |
cgeneric for a correlation matrix PC-prior.Build an cgeneric for a correlation matrix PC-prior.
cgeneric_pc_correl(n, base, iLtheta, iparams, ...)
## S3 method for class 'basecor'
cgeneric(
model,
lambda,
sigma.prior.reference,
sigma.prior.probability,
iparams,
cfixed,
...
)
n |
integer to define the size of the matrix,
same as |
base |
numeric vector, matrix or |
iLtheta |
integer vector to specify the (vectorized) position where 'theta' will be placed in the (lower triangle) Cholesky factorization of the correlation matrix. |
iparams |
integer vector with length equal |
... |
additional arguments passed on to
|
model |
a |
lambda |
the parameter for the exponential prior on the radius of the sphere, see details in the PC-multivariate vignette. |
sigma.prior.reference |
numeric vector to set the reference
for each standard deviation parameter for its PC-prior.
If missing, the model will be assumed as for a correlation.
Note: |
sigma.prior.probability |
numeric vector with to
set the probability statement of the PC prior for each
marginal variance parameters. The probability statement is
P(sigma < |
cfixed |
integer vector to specify which correlation
parameters are treated as known and fixed.
By default all correlation parameters are treated as unknown.
Example: if |
The parametrization is set as in basecor() and the base
is used to define an informative prior, as derived in
the pcmultivariate vignette.
a cgeneric object, see INLAtools::cgeneric() for details.
cgeneric(basecor): Build a cgeneric for a basecor.
Daniel Simpson, H\aa vard Rue, Andrea Riebler, Thiago G. Martins and Sigrunn H. S\o rbye (2017). Penalising Model Component Complexity: A Principled, Practical Approach to Constructing Priors. Statistical Science 2017, Vol. 32, No. 1, 1–28. <doi 10.1214/16-STS576>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.