| internal-utils | R Documentation |
Internal functions.
p_iLtheta_fncheck(p, iLtheta)
m_iparams_fncheck(m, iparams)
KLD10(C1, C0, L1, L0)
pcSigmasCheck(nsigmas, sigma.prior.reference, sigma.prior.probability)
p |
integer (needed if |
iLtheta |
integer vector or 'graphpcor' to specify the (vectorized)
position where 'theta' is placed in the initial (before the fill-in)
Cholesky (lower triangle) factor. If missing, default, assumes
the dense case as |
m |
integer to specify the number of parameters |
iparams |
integer ordered vector with length equal
the number of parameters used to specify common parameter values.
Default is |
C1 |
is a correlation matrix. |
C0 |
is a correlation matrix of the base model. |
L1 |
is the Cholesky of |
L0 |
is the Cholesky of |
nsigmas |
number of parameters. |
sigma.prior.reference |
numeric vector to set the reference for each standard deviation parameter for its PC-prior. |
sigma.prior.probability |
numeric vector with to
set the probability statement of the PC prior for each
marginal variance parameters. The probability statement is
P(sigma < |
By assuming equal mean vector we have
KLD = 0.5( tr(C0^{-1}C1) -p - log(|C1|) + log(|C0|) )
p_iLtheta_fncheck(): Function to deal with p and iLtheta
m_iparams_fncheck(): Function to deal with m and iparams
KLD10(): Compute the KLD between two multivariate Gaussian
distributions, assuming equal mean vector
pcSigmasCheck(): Check the PC-prior arguments for sigma.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.