| param-utils | R Documentation |
Internal functions to map between Euclidean and spherical coordinates
rphi2x(rphi)
x2rphi(x)
rtheta(n, lambda = 1, R, theta.base)
dtheta(theta, lambda, theta.base, H.elements)
rphi |
numeric vector where the first element is the radius and the remaining are the angles |
x |
parameters in the Euclidean space to be converted |
n |
integer to define the size of the correlation matrix |
lambda |
numeric as the parameter for the Exponential distribution of the radius |
R |
scaling matrix (square root of the Hessian around the base model) |
theta.base |
numeric vector of the base model |
theta |
numeric vector of length |
H.elements |
list output of theta2H |
For details, please see the wikipedia entry on 'N-sphere' at N-sphere
rphi2x(): Map between spherical to Euclidean coordinates
x2rphi(): Transform from Euclidean coordinates to spherical
rtheta(): Drawn samples from the PC-prior for correlation
dtheta(): PC-prior density for the correlation matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.